@@ -29,7 +29,6 @@ import json
 
 from ..helpers import getLogger
 from .. import version
-import collections
 
 # Gets the instance of the logger.
 logSys = getLogger(__name__)
@@ -257,7 +256,7 @@ class Transmitter:
 			actionname = command[2]
 			actionkey = command[3]
 			action = self.__server.getAction(name, actionname)
-			if isinstance(getattr(action, actionkey, None), collections.Callable):
+			if callable(getattr(action, actionkey, None)):
 				actionvalue = json.loads(command[4]) if len(command)>4 else {}
 				return getattr(action, actionkey)(**actionvalue)
 			else:
@@ -329,13 +328,13 @@ class Transmitter:
 			return [
 				key for key in dir(action)
 				if not key.startswith("_") and
-					not isinstance(getattr(action, key), collections.Callable)]
+					not callable(getattr(action, key))]
 		elif command[1] == "actionmethods":
 			actionname = command[2]
 			action = self.__server.getAction(name, actionname)
 			return [
 				key for key in dir(action)
-				if not key.startswith("_") and isinstance(getattr(action, key), collections.Callable)]
+				if not key.startswith("_") and callable(getattr(action, key))]
 		raise Exception("Invalid command (no get action or not yet implemented)")
 	
 	def status(self, command):
